                    PPI::Document
[    1,   1,   1 ]   PPI::Token::Comment  	'#!/usr/bin/perl\n'
[    2,   1,   1 ]   PPI::Token::Whitespace  	'\n'
                      PPI::Statement
[    3,   1,   1 ]     PPI::Token::Word  	'print'
[    3,   6,   6 ]     PPI::Token::Whitespace  	' '
[    3,   7,   7 ]     PPI::Token::Quote::Double  	'"Hello world!\n"'
[    3,  23,  23 ]     PPI::Token::Structure  	';'
[    3,  24,  24 ]   PPI::Token::Whitespace  	'\n'
