PPI::Document
   PPI::Token::Comment  	'#!/usr/bin/perl\n'
   PPI::Token::Whitespace  	'\n'
   PPI::Statement
      PPI::Token::Word  	'print'
      PPI::Token::Whitespace  	' '
      PPI::Token::Quote::Double  	'"Hello world!\n"'
      PPI::Token::Structure  	';'
   PPI::Token::Whitespace  	'\n'
