9092796  PPI::Document
9093108    PPI::Token::Comment  	'#!/usr/bin/perl\n'
9093480    PPI::Token::Whitespace  	'\n'
9050796    PPI::Statement
9093720      PPI::Token::Word  	'print'
9093948      PPI::Token::Whitespace  	' '
9049488      PPI::Token::Quote::Double  	'"Hello world!\n"'
9050304      PPI::Token::Structure  	';'
9050292    PPI::Token::Whitespace  	'\n'
